# datasette-glitch

[![PyPI](https://img.shields.io/pypi/v/datasette-glitch.svg)](https://pypi.org/project/datasette-glitch/)
[![Changelog](https://img.shields.io/github/v/release/simonw/datasette-glitch?label=changelog)](https://github.com/simonw/datasette-glitch/releases)
[![License](https://img.shields.io/badge/license-Apache%202.0-blue.svg)](https://github.com/simonw/datasette-glitch/blob/master/LICENSE)

Utilities to help run Datasette on Glitch

## Installation

Install this plugin in the same environment as Datasette.

    $ pip install datasette-glitch

## Usage

This plugin outputs a special link which will sign you into Datasette as the root user.

Click Tools -> Logs in the Glitch editor interface after your app starts to see the link.
